﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

// Open the Add References dialog. On the COM tab, select
// "Microsoft Word 12.0 Object Library" (or whatever version you
// have installed on your system). 

using Word = Microsoft.Office.Interop.Word;

namespace howto_word_picture_per_page
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Allow multi-select.
        // (You could set this in the Form Designer.)
        private void Form1_Load(object sender, EventArgs e)
        {
            ofdPictures.Multiselect = true;
        }

        // Let the user select the pictures.
        private void btnSelectPictures_Click(object sender, EventArgs e)
        {
            if (ofdPictures.ShowDialog() == DialogResult.OK)
                lstFiles.DataSource = ofdPictures.FileNames;
        }

        // Create the Word document.
        private void btnCreateDocument_Click(object sender, EventArgs e)
        {
            // Get the Word application object.
            Word._Application word_app = new Word.ApplicationClass();

            // Make Word visible (optional).
            word_app.Visible = true;

            // Create the Word document.
            object missing = Type.Missing;
            Word._Document word_doc = word_app.Documents.Add(ref missing, ref missing,
                ref missing, ref missing);

            // Make one page per picture.
            object collapse_end = Word.WdCollapseDirection.wdCollapseEnd;
            object page_break = Word.WdBreakType.wdPageBreak;
            for (int i = 0; i < lstFiles.Items.Count; i++)
            {
                // Get the file's name.
                string filename = (string)lstFiles.Items[i];

                // Go to the end of the document.
                Word.Range range = word_doc.Paragraphs.Last.Range;

                // Add the picture to the range.
                Word.InlineShape inline_shape =
                    range.InlineShapes.AddPicture(
                        filename, ref missing, ref missing,
                        ref missing);

                // Add a paragraph.
                range.InsertParagraphAfter();

                // Add a caption.
                FileInfo file_info = new FileInfo(filename);
                range.InsertAfter("Picture " +
                    i.ToString() + ": " + file_info.Name);

                // If this isn't the last page, insert a page break.
                if (i < lstFiles.Items.Count - 1)
                {
                    range.Collapse(ref collapse_end);
                    range.InsertBreak(ref page_break);
                }
            }

            // Save the document.
            object doc_filename = Path.GetFullPath(
                Path.Combine(Application.StartupPath, "..\\..")) +
                "\\pictures.docx";
            word_doc.SaveAs(ref doc_filename, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing);

            // Close.
            object save_changes = false;
            word_doc.Close(ref save_changes, ref missing, ref missing);
            word_app.Quit(ref save_changes, ref missing, ref missing);

            MessageBox.Show("Done");
        }
    }
}
